@@ -78,19 +78,11 @@ function url_encode(string) {
     return encodedString;
 }
 
-function createOAuthHeader(site, type, url, credentials, authParameters, parameters, body)
+function createOAuthHeader(type, url, credentials, authParameters, parameters, body)
 {
-    var consumer_key;
-    var consumer_secret;
+    var consumer_key = Sharing.twitterId;
+    var consumer_secret = Sharing.twitterSecret;
 
-    if (site == "vimeo") {
-        consumer_key = Vimeo.clientId;
-        consumer_secret = Vimeo.clientSecret;
-    }
-    else if (site == "twitter") {
-        consumer_key = Sharing.twitterId;
-        consumer_secret = Sharing.twitterSecret;
-    }
 //    console.log(consumer_key, consumer_secret)
 
     var timestamp =  getTimestamp();
