@@ -34,7 +34,7 @@ public:
     void setNetworkAccessManager(QNetworkAccessManager *manager);
     QString getUsername() const { return username; }
     QString getAccessToken() const { return accessToken; }
-    bool getUserSignedIn() const { return !(accessToken.isEmpty()); }
+    bool getUserSignedIn() const { return !accessToken.isEmpty(); }
     bool isUploading() const { return uploading; }
 
 public slots:
